==> mingw-w64-aws-sdk-cpp-1.9.311-1.src.tar.zst: aws-sdk-cpp-1.9.311/aws-cpp-sdk-lookoutmetrics/include/aws/lookoutmetrics/model/BackTestConfiguration.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/lookoutmetrics/LookoutMetrics_EXPORTS.h>

namespace Aws
{
namespace Utils
{
namespace Json
{
  class JsonValue;
  class JsonView;
} // namespace Json
} // namespace Utils
namespace LookoutMetrics
{
namespace Model
{

  /**
   * <p>Settings for backtest mode.</p><p><h3>See Also:</h3>   <a
   * href="http://docs.aws.amazon.com/goto/WebAPI/lookoutmetrics-2017-07-25/BackTestConfiguration">AWS
   * API Reference</a></p>
   */
  class AWS_LOOKOUTMETRICS_API BackTestConfiguration
  {
  public:
    BackTestConfiguration();
    BackTestConfiguration(Aws::Utils::Json::JsonView jsonValue);
    BackTestConfiguration& operator=(Aws::Utils::Json::JsonView jsonValue);
    Aws::Utils::Json::JsonValue Jsonize() const;


    /**
     * <p>Run a backtest instead of monitoring new data.</p>
     */
    inline bool GetRunBackTestMode() const{ return m_runBackTestMode; }

    /**
     * <p>Run a backtest instead of monitoring new data.</p>
     */
    inline bool RunBackTestModeHasBeenSet() const { return m_runBackTestModeHasBeenSet; }

    /**
     * <p>Run a backtest instead of monitoring new data.</p>
     */
    inline void SetRunBackTestMode(bool value) { m_runBackTestModeHasBeenSet = true; m_runBackTestMode = value; }

    /**
     * <p>Run a backtest instead of monitoring new data.</p>
     */
    inline BackTestConfiguration& WithRunBackTestMode(bool value) { SetRunBackTestMode(value); return *this;}

  private:

    bool m_runBackTestMode;
    bool m_runBackTestModeHasBeenSet;
  };

} // namespace Model
} // namespace LookoutMetrics
} // namespace Aws

==> mingw-w64-aws-sdk-cpp-1.10.9-1.src.tar.zst: aws-sdk-cpp-1.10.9/aws-cpp-sdk-lookoutmetrics/include/aws/lookoutmetrics/model/BackTestConfiguration.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/lookoutmetrics/LookoutMetrics_EXPORTS.h>

namespace Aws
{
namespace Utils
{
namespace Json
{
  class JsonValue;
  class JsonView;
} // namespace Json
} // namespace Utils
namespace LookoutMetrics
{
namespace Model
{

  /**
   * <p>Settings for backtest mode.</p><p><h3>See Also:</h3>   <a
   * href="http://docs.aws.amazon.com/goto/WebAPI/lookoutmetrics-2017-07-25/BackTestConfiguration">AWS
   * API Reference</a></p>
   */
  class AWS_LOOKOUTMETRICS_API BackTestConfiguration
  {
  public:
    BackTestConfiguration();
    BackTestConfiguration(Aws::Utils::Json::JsonView jsonValue);
    BackTestConfiguration& operator=(Aws::Utils::Json::JsonView jsonValue);
    Aws::Utils::Json::JsonValue Jsonize() const;


    /**
     * <p>Run a backtest instead of monitoring new data.</p>
     */
    inline bool GetRunBackTestMode() const{ return m_runBackTestMode; }

    /**
     * <p>Run a backtest instead of monitoring new data.</p>
     */
    inline bool RunBackTestModeHasBeenSet() const { return m_runBackTestModeHasBeenSet; }

    /**
     * <p>Run a backtest instead of monitoring new data.</p>
     */
    inline void SetRunBackTestMode(bool value) { m_runBackTestModeHasBeenSet = true; m_runBackTestMode = value; }

    /**
     * <p>Run a backtest instead of monitoring new data.</p>
     */
    inline BackTestConfiguration& WithRunBackTestMode(bool value) { SetRunBackTestMode(value); return *this;}

  private:

    bool m_runBackTestMode;
    bool m_runBackTestModeHasBeenSet = false;
  };

} // namespace Model
} // namespace LookoutMetrics
} // namespace Aws
